@@ -1,5 +1,5 @@
 ;; guile-gnome
-;; Copyright (C) 2003,2004 Andy Wingo <wingo at pobox dot com>
+;; Copyright (C) 2003,2004,2015 Andy Wingo <wingo at pobox dot com>
 
 ;; This program is free software; you can redistribute it and/or    
 ;; modify it under the terms of the GNU General Public License as   
@@ -49,15 +49,15 @@
                 gruntime-error
                 gtype-instance-destroy!))
 
-(dynamic-call "scm_init_gnome_gobject_gc"
-              (dynamic-link *guile-gnome-gobject-lib-path*))
-(dynamic-call "scm_init_gnome_gobject_types"
-              (dynamic-link *guile-gnome-gobject-lib-path*))
+(eval-when (expand load eval)
+  (dynamic-call "scm_init_gnome_gobject_gc"
+		(dynamic-link *guile-gnome-gobject-lib-path*))
+  (dynamic-call "scm_init_gnome_gobject_types"
+		(dynamic-link *guile-gnome-gobject-lib-path*)))
 
 (define (gruntime-error format-string . args)
   "Signal a runtime error. The error will be thrown to the key
 @code{gruntime-error}."
-  (save-stack)
   (scm-error 'gruntime-error #f format-string args '()))
 
 
@@ -65,12 +65,11 @@
 ;;; {Base Class Hierarchy]
 ;;;
 
-
 (define-class-with-docs <gtype-class> (<class>)
   "The metaclass of all GType classes. Ensures that GType classes have a
 @code{gtype} slot, which records the primitive GType information for
 this class."
-  (gtype #:class <read-only-slot>))
+  (gtype #:class <foreign-slot>))
 
 (define-method (initialize (class <gtype-class>) initargs)
   (let ((gtype-name (or (get-keyword #:gtype-name initargs #f)
@@ -78,17 +77,17 @@ this class."
                                         (pk initargs)))))
     ;; allow gtype-name of #t for base classes without gtypes (e.g.
     ;; <gtype-instance>)
-    (%gtype-class-bind class (if (eq? gtype-name #t)
-                                 #f
-                                 gtype-name))
+    (if (not (eq? gtype-name #t))
+        (%gtype-class-bind class gtype-name))
     (next-method)
     (%gtype-class-inherit-magic class)))
 
 (define-method (write (class <gtype-class>) file)
   (format file "#<~a ~a>" (class-name (class-of class)) (class-name class)))
 
-(dynamic-call "scm_init_gnome_gobject_types_gtype_class"
-              (dynamic-link *guile-gnome-gobject-lib-path*))
+(eval-when (expand load eval)
+  (dynamic-call "scm_init_gnome_gobject_types_gtype_class"
+		(dynamic-link *guile-gnome-gobject-lib-path*)))
 
 (define-class-with-docs <gtype-instance> ()
   "The root class of all instantiatable GType classes. Adds a slot,
@@ -102,14 +101,15 @@ value."
   (next-method)
   (%gtype-instance-construct instance initargs))
 
-(dynamic-call "scm_init_gnome_gobject_types_gtype_instance"
-              (dynamic-link *guile-gnome-gobject-lib-path*))
+(eval-when (expand load eval)
+  (dynamic-call "scm_init_gnome_gobject_types_gtype_instance"
+		(dynamic-link *guile-gnome-gobject-lib-path*)))
+
 
 ;;;
 ;;; {Misc]
 ;;;
 
-
 (define (class-name->gtype-name class-name)
   "Convert the name of a class into a suitable name for a GType. For
 example:
